darkhistory.history.histools.IonRSArray — DarkHistory documentation

# darkhistory.history.histools.IonRSArray

class `darkhistory.history.histools.` `IonRSArray`(val_arr, x_arr, rs_arr, in_eng=None, eng=None)

  Array of objects indexed by ionization and redshift.

  Parameters: | val_arr : ndarray Array of objects, indexed by (rs, …), (xH, rs, …) or (xH, xHe, rs, …) x_arr : ndarray List of x values corresponding to val_arr, either None, 1D array or 3D array indexed by (xH, xHe), with each entry being [xH, xHe]. rs_arr : ndarray List of redshift values corresponding to val_arr. in_eng : ndarray Injection energy abscissa of entries of val_arr. eng : ndarray Energy abscissa of entries of val_arr.
  Attributes: | interp_func : function An interpolation function over ionization and redshift.

  `__init__`(val_arr, x_arr, rs_arr, in_eng=None, eng=None)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(val_arr, x_arr, rs_arr[, in_eng, eng]) | Initialize self.

#### Previous topic

darkhistory.history.histools

#### Next topic

darkhistory.history.histools.IonRSInterp

### This Page

Show Source